@@ -50,15 +50,15 @@ class BadInput(UTMTestCase):
         '''from_latlon should fail with out-of-bounds input'''
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, -100, 0)
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, -80.1, 0)
-        UTM.from_latlon(-80, 0)
-        UTM.from_latlon(84, 0)
+        for i in xrange(-8000, 8400):
+            UTM.from_latlon(i / 100.0, 0)
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, 84.1, 0)
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, 100, 0)
 
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, 0, -300)
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, 0, -180.1)
-        UTM.from_latlon(0, -180)
-        UTM.from_latlon(0, 180)
+        for i in range(-18000, 18000):
+            UTM.from_latlon(0, i / 100.0)
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, 0, 180.1)
         self.assertRaises(UTM.OutOfRangeError, UTM.from_latlon, 0, 300)
 
@@ -71,14 +71,14 @@ class BadInput(UTMTestCase):
         '''from_latlon should fail with out-of-bounds input'''
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 0, 5000000, 32, 'U')
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 99999, 5000000, 32, 'U')
-        for i in range(100000, 999999, 4242):
+        for i in range(100000, 999999, 100):
             UTM.to_latlon(i, 5000000, 32, 'U')
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 1000000, 5000000, 32, 'U')
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 100000000000, 5000000, 32, 'U')
 
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 500000, -100000, 32, 'U')
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 500000, -1, 32, 'U')
-        for i in range(10, 10000000, 4242):
+        for i in range(10, 10000000, 100):
             UTM.to_latlon(500000, i, 32, 'U')
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 500000, 10000001, 32, 'U')
         self.assertRaises(UTM.OutOfRangeError, UTM.to_latlon, 500000, 50000000, 32, 'U')
